define(
//begin v1.x content
{
	"HKD_displayName": "دولار هونغ كونغ",
	"CNY_displayName": "يوان صيني",
	"JPY_displayName": "ين ياباني",
	"JPY_symbol": "JP¥",
	"USD_displayName": "دولار أمريكي",
	"CAD_symbol": "CA$",
	"GBP_displayName": "جنيه إسترليني",
	"CHF_displayName": "فرنك سويسري",
	"CNY_symbol": "CN¥",
	"EUR_displayName": "يورو",
	"GBP_symbol": "UK£",
	"CAD_displayName": "دولار كندي",
	"USD_symbol": "US$",
	"EUR_symbol": "€",
	"AUD_displayName": "دولار أسترالي",
	"CHF_symbol": "CHF",
	"HKD_symbol": "HK$",
	"AUD_symbol": "AU$"
}
//end v1.x content
);